==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/StepInfoBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StepInfoBuilder extends io.fabric8.openshift.api.model.StepInfoFluentImpl<io.fabric8.openshift.api.model.StepInfoBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.StepInfo,io.fabric8.openshift.api.model.StepInfoBuilder>{
  public StepInfoBuilder() {
    this(false);
  }
  public StepInfoBuilder(java.lang.Boolean validationEnabled) {
    this(new StepInfo(), validationEnabled);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfoFluent<?> fluent) {
    this(fluent, false);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfoFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StepInfo(), validationEnabled);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfoFluent<?> fluent,io.fabric8.openshift.api.model.StepInfo instance) {
    this(fluent, instance, false);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfoFluent<?> fluent,io.fabric8.openshift.api.model.StepInfo instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDurationMilliseconds(instance.getDurationMilliseconds()); 
    fluent.withName(instance.getName()); 
    fluent.withStartTime(instance.getStartTime()); 
    this.validationEnabled = validationEnabled; 
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfo instance) {
    this(instance,false);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfo instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDurationMilliseconds(instance.getDurationMilliseconds()); 
    this.withName(instance.getName()); 
    this.withStartTime(instance.getStartTime()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.StepInfoFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.StepInfo build() {
    StepInfo buildable = new StepInfo(fluent.getDurationMilliseconds(),fluent.getName(),fluent.getStartTime());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StepInfoBuilder that = (StepInfoBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/StepInfoBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StepInfoBuilder extends io.fabric8.openshift.api.model.StepInfoFluentImpl<io.fabric8.openshift.api.model.StepInfoBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.StepInfo,io.fabric8.openshift.api.model.StepInfoBuilder>{
  public StepInfoBuilder() {
    this(false);
  }
  public StepInfoBuilder(java.lang.Boolean validationEnabled) {
    this(new StepInfo(), validationEnabled);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfoFluent<?> fluent) {
    this(fluent, false);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfoFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StepInfo(), validationEnabled);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfoFluent<?> fluent,io.fabric8.openshift.api.model.StepInfo instance) {
    this(fluent, instance, false);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfoFluent<?> fluent,io.fabric8.openshift.api.model.StepInfo instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDurationMilliseconds(instance.getDurationMilliseconds()); 
    fluent.withName(instance.getName()); 
    fluent.withStartTime(instance.getStartTime()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfo instance) {
    this(instance,false);
  }
  public StepInfoBuilder(io.fabric8.openshift.api.model.StepInfo instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDurationMilliseconds(instance.getDurationMilliseconds()); 
    this.withName(instance.getName()); 
    this.withStartTime(instance.getStartTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.StepInfoFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.StepInfo build() {
    StepInfo buildable = new StepInfo(fluent.getDurationMilliseconds(),fluent.getName(),fluent.getStartTime());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StepInfoBuilder that = (StepInfoBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
